@@ -75,6 +75,10 @@ class ClBuilderUpdateAction(Action):
                 {'name': 'clear_log',
                  'method': 'Builder.clear_log(cl_builder_id_path)',
                  },
+                {'name': 'allow_scan_binhost',
+                 'method': 'Builder.setVariable("cl_builder_binhost_scan_set",'
+                           '"on",True)'
+                },
                 {'name': 'apply_template',
                  'message': __("Configuring build"),
                  'method': 'Builder.applyTemplates(cl_builder_target,False,'
