@@ -26,6 +26,7 @@ from calculate.lib.utils.grub import GrubCommand
 from calculate.lib.utils.portage import getSquashList
 from calculate.lib.variables.system import RootType
 from .action import Actions
+import linux as vars_linux
 from calculate.install import distr
 from calculate.lib.utils.device import getUdevDeviceInfo, humanreadableSize
 from calculate.lib.utils.files import (isMount, process, typeFile,
@@ -38,7 +39,7 @@ from ..build_storage import BuildStorage, Build
 from ..drive_spool import DriveSpool
 from .action import Actions as BuilderActions
 from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
-                                    TableVariable)
+                                    TableVariable, WRITEABLE)
 from functools import wraps
 
 _ = lambda x: x
@@ -1621,3 +1622,34 @@ class VariableClBuilderEixRepositories(ReadonlyVariable):
             x for x in chain(
                 reversed(self.Get('update.cl_update_rep_name')),
                 self.Get('builder.cl_builder_other_rep_name')))
+
+
+class VariableClBuilderBinhostStableSet(
+    vars_linux.VariableClBuilderLinuxDatavars):
+    """
+    Удлять лишние файлы из репозиториев (например созданные пользователем)
+    """
+    type = "bool"
+    value = "on"
+    mode = WRITEABLE
+
+    opt = ["--stable"]
+
+    def init(self):
+        self.label = _("Check the repositories integrity")
+        self.help = _("use only stable updates")
+
+    def prepare_vars(self, dvbl):
+        pass
+
+    def get(self):
+        if self.Get('cl_action') in Actions.WorkAssemble:
+            dv = self.target_data()
+            return dv.Get('update.cl_update_binhost_stable_opt_set')
+        return self.Get('update.cl_update_binhost_stable_opt_set')
+
+class VariableClBuilderBinhostScanSet(Variable):
+    """
+    Сканировать или нет зеркала (переменная переключается во время действия)
+    """
+    value = "off"
