@@ -176,7 +176,8 @@ class Wsdl(WsdlBase):
             'groups': [
                 lambda group: group(
                     _("Update the Build"),
-                    normal=('cl_builder_prepared_id',),
+                    normal=('cl_builder_prepared_id',
+                            'cl_builder_binhost_stable_set'),
                     expert=(
                         'update.cl_update_sync_only_set',
                         'update.cl_update_other_set',
